<?php
/**
 * Plugin Name: CarDealerPress Theme Extender
 * Plugin URI: 
 * Author: DealerTrend, Inc.
 * Author URI: http://www.dealertrend.com
 * Description: Allows a custom theme to be added to the CarDealerPress Plugin without CarDealerPress updates overwriting custom theme changes
 * Version: 4.4.1601.00
 * License: GPLv2 or later
 */

/****************
****************
Place all main files (e.g. list.php, detail.php, style.css, script.js) in root directoy of CarDealerPress Theme Extender
Inventory php files must be named list.php and detail.php
****************
****************/
class cdp_theme_extender{
	
	private $style_url;
	private $script_url;
	
	function __construct(){
		if( class_exists('Wordpress\Plugins\CarDealerPress\Inventory\Api\cdp_plugin') ){
			$this->set_theme_urls();
			$this->theme_file_check();
			/****************
			Add Extra Features Below
			****************/
			$this->include_extra_php_files();	
		}
	}
		
	function set_theme_urls() {
		$theme_dir = scandir( dirname( __FILE__ ) );
		foreach( $theme_dir as $file ) {
			$ext = pathinfo($file, PATHINFO_EXTENSION);
			if( $ext == 'js' ) {
				$this->script_url = plugins_url( $file, __FILE__ );
			}
			if( $ext == 'css' ) {
				$this->style_url = plugins_url( $file, __FILE__ );
			}
		}
	}
	
	function theme_file_check(){
		if( file_exists( dirname( __FILE__ ).'/list.php') && file_exists( dirname( __FILE__ ).'/detail.php') ){
			$this->apply_filter_hook();
		}
		
	}
	
	function apply_filter_hook(){
		add_filter( 'cdp_theme_path', array($this, 'get_extended_theme_path') );
		add_filter( 'cdp_inventory_style_url', array($this, 'get_stylesheet_url') );
		add_filter( 'cdp_inventory_script_url', array($this, 'get_script_url') );
		add_filter( 'cdp_print', array($this, 'get_extended_print') );
	}
	
	function get_extended_theme_path(){
		$path = dirname( __FILE__ );
		return $path;
	}
	
	function get_stylesheet_url(){
		if( $this->style_url ){
			return $this->style_url;
		}
	}
	
	function get_script_url(){
		if( $this->script_url ){
			return $this->script_url;
		}
	}
	
	function get_extended_print(){
		if( file_exists( dirname( __FILE__ ).'/print.php' ) ){
			return dirname( __FILE__ ).'/print.php';
		}
	}
	
	function include_extra_php_files(){
		//require_once( dirname( __FILE__ ) . '/extra/name_of_your_file' );
	}
}

$extended_theme = new cdp_theme_extender();
?>